
# housekeeping
library(lmtest)
library(sandwich)
rm(list=ls())

###########################################################
# SET THE WORKING DIRECTORY HERE, or save folder in Desktop 
setwd("~/Desktop/replication/")
###########################################################

# Import dataset
library(readxl)
d <- read_excel("data/placebo2010.xlsx")


################################################
# Figure 4: pre-post political corruption cycle
################################################

# Exclude weekends
d$day <- weekdays(d$date)
d <- d[d$day!="Saturday" & d$day!="Sunday", ]

d$electoral_calendar=d$election2010
d$pre_post=ifelse(d$election2010<0,1,0)
d$pre_post=ifelse(is.na(d$election2010),NA,d$pre_post)

# set window
window <- 1:37

# create empty matrices to store results
amount <- matrix(ncol = 3, nrow = 37)
collection <- matrix(ncol = 3, nrow = 37)
delivery <- matrix(ncol = 3, nrow = 37)

# compute regression for different windows using a for-loop
for(i in 3:37){
  d2 <- d[abs(d$electoral_calendar)<i, ]
  
  lm1 <- lm(collected_amount ~ pre_post, data = d2)
  
  selm1 <- coeftest(lm1, vcov = vcovHC(lm1, type = "HC1"))[2,2]
  critical.t <- abs(qt(p = 0.05, df = lm1$df.residual))
  
  amount[i,1] <- lm1$coefficients[2] 
  amount[i,2] <- lm1$coefficients[2] + selm1*critical.t
  amount[i,3] <- lm1$coefficients[2] - selm1*critical.t
  
  lm2 <- lm(collection ~ pre_post, data = d2)
  
  selm2 <- coeftest(lm2, vcov = vcovHC(lm2, type = "HC1"))[2,2]
  critical.t <- abs(qt(p = 0.05, df = lm2$df.residual))
  
  collection[i,1] <- lm2$coefficients[2] 
  collection[i,2] <- lm2$coefficients[2] + selm2*critical.t
  collection[i,3] <- lm2$coefficients[2] - selm2*critical.t
  
  lm3 <- lm(delivery ~ pre_post, data = d2)
  
  selm3 <- coeftest(lm3, vcov = vcovHC(lm3, type = "HC1"))[2,2]
  critical.t <- abs(qt(p = 0.05, df = lm3$df.residual))
  
  delivery[i,1] <- lm3$coefficients[2] 
  delivery[i,2] <- lm3$coefficients[2] + selm3*critical.t
  delivery[i,3] <- lm3$coefficients[2] - selm3*critical.t
  
}

# save coefficients for 1, 2, 3 and 4 week window

size7days <- amount[7,1]
collection7days <- collection[7,1]
delivery7days <- delivery[7,1]

size14days <- amount[14,1]
collection14days <- collection[14,1]
delivery14days <- delivery[14,1]

size21days <- amount[21,1]
collection21days <- collection[21,1]
delivery21days <- delivery[21,1]

size28days <- amount[28,1]
collection28days <- collection[28,1]
delivery28days <- delivery[28,1]

# plot the results

png(file="out/appendix_2010placebo.png")
par(mfrow = c(1,3), mar = c(5,3,4,1))
plot(y = amount[,1],
     x = window,
     lwd = 3,
     ylim = c(-0.2,1.8),
     type = "l",
     main = "Total daily kickbacks",
     xlab = "Time window (in days)",
     ylab = "")
par(new = TRUE)
plot(y = amount[,2],
     x = window,
     ylim = c(-0.2,1.8),
     type = "l",
     lty = 2,
     xlab = "",
     ylab = "",
     axes = FALSE)
par(new = TRUE)
plot(y = amount[,3],
     x = window,
     ylim = c(-0.2,1.8),
     type = "l",
     lty = 2,
     xlab = "",
     ylab = "",
     axes = FALSE)
abline(h = 0, col = "red", lty = 2)

plot(y = collection[,1],
     x = window,
     lwd = 3,
     ylim = c(-0.2,1),
     type = "l",
     main = "Episode of kickback",
     xlab = "Time window (in days)",
     ylab = "")
par(new = TRUE)
plot(y = collection[,2],
     x = window,
     ylim = c(-0.2,1),
     type = "l",
     lty = 2,
     xlab = "",
     ylab = "",
     axes = FALSE)
par(new = TRUE)
plot(y = collection[,3],
     x = window,
     ylim = c(-0.2,1),
     type = "l",
     lty = 2,
     xlab = "",
     ylab = "",
     axes = FALSE)
abline(h = 0, col = "red", lty = 2)

plot(y = delivery[,1],
     x = window,
     type = "l",
     lwd = 3,
     ylim = c(-0.2,1),
     main = "Episode of delivery",
     xlab = "Time window (in days)",
     ylab = "")
par(new = TRUE)
plot(y = delivery[,2],
     x = window,
     ylim = c(-0.2,1),
     type = "l",
     lty = 2,
     xlab = "",
     ylab = "",
     axes = FALSE)
par(new = TRUE)
plot(y = delivery[,3],
     x = window,
     ylim = c(-0.2,1),
     type = "l",
     lty = 2,
     xlab = "",
     ylab = "",
     axes = FALSE)
abline(h = 0, col = "red", lty = 2)
dev.off()
